@@ -5,7 +5,7 @@ Renamed from array_parser.py for clarity.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, Mapping, Optional
+from typing import TYPE_CHECKING, Any, Callable, Mapping
 
 from pyopenapi_gen import IRSchema
 
@@ -18,14 +18,14 @@ if TYPE_CHECKING:
 
 
 def _parse_array_items_schema(
-    parent_schema_name: Optional[str],
+    parent_schema_name: str | None,
     items_node_data: Mapping[str, Any],
     context: ParsingContext,
     parse_fn: Callable[  # Accepts the main schema parsing function
-        [Optional[str], Optional[Mapping[str, Any]], ParsingContext, int], IRSchema
+        [str | None, Mapping[str, Any] | None, ParsingContext, int], IRSchema
     ],
     max_depth: int,
-) -> Optional[IRSchema]:
+) -> IRSchema | None:
     """Parses the 'items' sub-schema of an array.
 
     Args:
