@@ -60,7 +60,7 @@ class TestOpenAPISchemaResolver:
     def test_resolve_schema__string_type_optional__returns_optional_str(self, resolver, mock_context) -> None:
         """
         Scenario: Resolving optional string schema
-        Expected Outcome: Returns Optional[str] type
+        Expected Outcome: Returns str | None type
         """
         # Arrange
         schema = IRSchema(type="string")
@@ -149,7 +149,7 @@ class TestOpenAPISchemaResolver:
     def test_resolve_schema__object_no_properties__returns_dict_any(self, resolver, mock_context) -> None:
         """
         Scenario: Resolving object schema without properties
-        Expected Outcome: Returns Dict[str, Any] type
+        Expected Outcome: Returns dict[str, Any] type
         """
         # Arrange
         schema = IRSchema(type="object")
@@ -158,7 +158,7 @@ class TestOpenAPISchemaResolver:
         result = resolver.resolve_schema(schema, mock_context)
 
         # Assert
-        assert result.python_type == "Dict[str, Any]"
+        assert result.python_type == "dict[str, Any]"
         mock_context.add_import.assert_any_call("typing", "Dict")
         mock_context.add_import.assert_any_call("typing", "Any")
 
@@ -498,6 +498,38 @@ class TestOpenAPISchemaResolver:
         assert result.python_type == "UUID"
         mock_context.add_import.assert_called_with("uuid", "UUID")
 
+    def test_resolve_schema__string_with_format_binary__returns_bytes_type(self, resolver, mock_context) -> None:
+        """
+        Scenario: Resolving string schema with binary format
+        Expected Outcome: Returns bytes type (built-in, no import needed)
+        """
+        # Arrange
+        schema = IRSchema(type="string", format="binary")
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=True)
+
+        # Assert
+        assert result.python_type == "bytes"
+        assert not result.is_optional
+
+    def test_resolve_schema__string_with_format_binary_optional__returns_optional_bytes(
+        self, resolver, mock_context
+    ) -> None:
+        """
+        Scenario: Resolving optional string schema with binary format
+        Expected Outcome: Returns optional bytes type
+        """
+        # Arrange
+        schema = IRSchema(type="string", format="binary")
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=False)
+
+        # Assert
+        assert result.python_type == "bytes"
+        assert result.is_optional
+
     def test_resolve_schema__string_with_inline_enum__logs_warning_returns_str(self, resolver, mock_context) -> None:
         """
         Scenario: Resolving string schema with inline enum
@@ -529,7 +561,7 @@ class TestOpenAPISchemaResolver:
 
         # Assert
         # Since target_schema has no generation_name, it should fall back to type handling
-        assert result.python_type == "Dict[str, Any]"  # object type without properties
+        assert result.python_type == "dict[str, Any]"  # object type without properties
 
     def test_resolve_schema__named_schema_lookup_in_schemas__resolves_target(
         self, resolver, mock_context, mock_ref_resolver
@@ -634,3 +666,93 @@ class TestOpenAPISchemaResolver:
         assert result.python_type == "User"
         assert result.import_module == "..models.user"  # Fallback path
         mock_context.add_import.assert_called_with("..models.user", "User")
+
+    def test_resolve_schema__null_type_schema__returns_any(self, resolver, mock_context) -> None:
+        """
+        Scenario: Resolving schema with type=None (null type)
+        Expected Outcome: Returns Any type instead of None type
+
+        This tests the fix for the null schema resolution bug where null schemas
+        were returning "None" instead of "Any", causing incorrect type assignments.
+        """
+        # Arrange
+        schema = IRSchema(type=None)
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=True)
+
+        # Assert
+        assert result.python_type == "Any"
+        assert not result.is_optional
+        mock_context.add_import.assert_called_with("typing", "Any")
+
+    def test_resolve_schema__null_type_schema_optional__returns_any_with_optional_flag(
+        self, resolver, mock_context
+    ) -> None:
+        """
+        Scenario: Resolving optional schema with type=None (null type)
+        Expected Outcome: Returns Any type with is_optional flag set
+
+        This tests that null schemas respect the required parameter.
+        The _resolve_null method correctly sets is_optional based on the required parameter.
+        """
+        # Arrange
+        schema = IRSchema(type=None)
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=False)
+
+        # Assert
+        assert result.python_type == "Any"
+        # Null schemas now correctly respect the required parameter and set is_optional=True when required=False
+        assert result.is_optional  # Correctly returns optional Any when required=False
+        mock_context.add_import.assert_called_with("typing", "Any")
+
+    def test_resolve_schema__schema_no_type_no_generation_name__returns_any(self, resolver, mock_context) -> None:
+        """
+        Scenario: Resolving schema with no type and no generation_name (null schema from OpenAPI)
+                  This matches the early detection logic for null schemas in schema_resolver.py
+        Expected Outcome: Returns Any type inline without creating placeholder type
+
+        This tests the fix for schemas like PostApiAuthLogoutRequestBody that were
+        incorrectly being assigned to unrelated fields. Null schemas should resolve
+        to Any directly.
+        """
+        # Arrange
+        schema = IRSchema(
+            type=None,
+            # No generation_name, no composition keywords
+        )
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=True)
+
+        # Assert
+        assert result.python_type == "Any"
+        mock_context.add_import.assert_called_with("typing", "Any")
+
+    def test_resolve_schema__schema_no_type_but_has_generation_name__resolves_as_named(
+        self, resolver, mock_context
+    ) -> None:
+        """
+        Scenario: Resolving schema with no type but has generation_name
+        Expected Outcome: Resolves as named schema, not as null schema
+
+        This verifies that schemas with generation_name are not treated as null schemas
+        even if they have no explicit type.
+        """
+        # Arrange
+        schema = IRSchema(
+            name="EmptyObject",  # Named schemas need both name and generation_name
+            type=None,
+            generation_name="EmptyObject",
+            final_module_stem="empty_object",
+        )
+
+        # Act
+        result = resolver.resolve_schema(schema, mock_context, required=True)
+
+        # Assert
+        assert result.python_type == "EmptyObject"
+        assert result.needs_import
+        # Should not resolve to Any for named schemas
